# PAGE UNDER CONSTRUCTION
quantum circuit dataset - this repository will be soon completed

===> dataset is already accessible!

There is already the dataset and qml experiments, some guide can be found in doc/sources

# MNISQ-quantum-circuit-dataset

This library provides machine learning datasets as a Qulacs's QuantumCircuit instance.

## How To Install

```
pip install git+https://github.com/FujiiLabCollaboration/MNISQ-quantum-circuit-dataset.git
```

## Directory structure
- `doc/source/notebooks` provides sample usage of this library.
- `mnisq` and `tests` contains python code.
- `generator_scripts` contains scripts used to generate datasets.
